from pulse import Pulse

if __name__ == "__main__":
    # Teste 1: Inicialização manual
    print("Teste 1: Inicialização manual")
    pulse = Pulse(app="Python Tests", group_id="a1ee521f-8850-4146-a498-4fd852a31685")
    print("✅ Inicialização OK\n")

    # Teste 2: Log manual
    print("Teste 2: Log manual")
    try:
        raise Exception('Erro de teste manual');
    except Exception as e:
        pulse.error(e, 'test.context');
        print('✅ Log manual enviado\n');

    # Teste 3: Log manual (informação)
    print("Teste 3: Log manual (informação)")
    pulse.info("Teste de informação", 'test.context');
    print('✅ Log manual enviado\n');

    print('\n✅ Testes concluídos!');
    print('📝 Verifique os logs [Pulse] acima para confirmar que os erros foram capturados');
    print('🌐 Verifique se os logs foram enviados para: https://api-pulse.704app.com.br/logs');